amachine.am_semantics API documentation

# amachine.am_semantics

View Source

     1from dataclasses import dataclass
     2
     3from .am_pattern    import Pattern
     4from .am_vocabulary import Vocabulary
     5
     6@dataclass
     7class SymbolSemantics :
     8	constext_invariant : bool = False
     9
    10
    11class Semantics :
    12
    13	def __init__(self) :
    14
    15		self.pattern_classes = {}
    16		self.symbol_classes  = {}

@dataclass
class SymbolSemantics: View Source

     8@dataclass
     9class SymbolSemantics :
    10	constext_invariant : bool = False

SymbolSemantics(constext_invariant: bool = False)
constext_invariant: bool = False
class Semantics: View Source

    13class Semantics :
    14
    15	def __init__(self) :
    16
    17		self.pattern_classes = {}
    18		self.symbol_classes  = {}

pattern_classes
symbol_classes